Talk Link

Transcript
Claims

- Harald Schafer
  I'm very excited about robotics, but I think we should be realistic. The big reason a lot of people went to self driving 10 years ago, including me, is because it seemed like a great applied robotics problem. That was easy. You have two dimensional actuators, you have simple rules of the road. As far as robotics goes, that's relatively easy. And then what happened is all these companies were optimistic and ended up not reaching their goals. And now all of a sudden everyone's switching to humanoid robotics, which from the beginning we always thought was harder. So I think it's just another hype wave. I don't think there's going to be humanoid robots in your house and we should be somewhat cautious about everything that's just a demo and is not shipping.
  (0:00:00)
- Jason Calcanis
  This week in Startups is brought to you by Tech Domains. Don't miss our Jam with JCAL contest. To apply and get more details, go to jamwithjcal Tech brought to you by Tech Domains. Vanta Compliance and security shouldn't be a deal breaker for startups to win new business. Vanta makes it easy for companies to get a SoC2 report fast. Twist listeners can get $1,000 off for limited time@vanta.com Twist and Micro1. Micro1 is an AI recruitment engine to hire world class engineers fast. Visit Micro1 AI Twist to open a talent search and get a two week free trial per hire. All right everybody, welcome back to the program. Very excited today to talk about self driving cars and autonomy. Feels to me like the autonomy endgame is upon us. We're seeing it in VTOLs, vertical takeoff and landing companies. We're seeing it with Waymo, Tesla and Today's guest, AI CTO, Harold Schaefer.
  (0:00:37)
- Jason Calcanis
  Welcome to the program. Harold, how are you?
  (0:01:46)
- Harald Schafer
  Thank you. Yeah, I'm doing great.
  (0:01:49)
- Jason Calcanis
  All right, so I had George on the program. I'm trying to remember what episode that was. Gosh, it was a while ago, I.
  (0:01:52)
- Harald Schafer
  Think like eight years ago or something.
  (0:02:00)
- Jason Calcanis
  Eight years ago. For the audience who doesn't know, explain what Hama AI is doing in the autonomous space and how it's different than Waymo and Tesla the other and Cruise, the other major players in the space.
  (0:02:02)
- Harald Schafer
  Right. So our goal is to solve robotics, general purpose robotics and in the meantime, you know, ship useful products to people that we can sell them for money that add value to their lives. And so today what that means is we sell a kit that runs software called Open Pilot that's completely open source and it's an ADAS upgrade for your car. So basically it will Take over the, you know, internal messaging of your car, and it can send gas commands, brake commands, and steering commands, and it can make it drive itself on the highway. So it's a bit like, you know, Tesla autopilot/fsd. Today from our users, over 50% of the miles are driven by open pilot. So it kind of gives you an idea of, you know, how much of the driving it does. It's a level two system. It's not fully autonomous. It just makes your drive more comfortable and it's kind of a value add.
  (0:02:18)
- Harald Schafer
  And, you know, as we progress with the technology, we want to, you know, increasingly make these things autonomous and, you know, make robotic products that we can sell.
  (0:03:07)
- Jason Calcanis
  Got it. So the mission of the company is General Robotics. The first product is this level two autonomy. Level two, I believe, correct me if I'm wrong here, is taking over two functions. And I believe the two functions that you tackled first with comma AI's kit is staying in the lane, adaptive cruise control. Am I correct?
  (0:03:15)
- Harald Schafer
  Yeah, exactly. But I mean, it's a bit more general than that. Like, it'll work if there's no lane lines, it'll work if there's no lead, that sort of stuff. It's just a gradual process to become more reliable. And eventually it will do everything and drive perfectly. But it's just an incremental game. But yeah, the goal is to do general purpose robotics. It's just that self driving right now, especially partial autonomy, is a very sensible place to make a product. It's something people are willing to pay for and something that's valuable, even if it's not perfect.
  (0:03:39)
- Jason Calcanis
  And so what does it cost to add this to your Toyota, your Honda, and how does that work for people who don't know about, you know, the different ports and how modern cars work in terms of controlling steering and speed? Maybe you could give us a little primer on that.
  (0:04:06)
- Harald Schafer
  Yeah, so it's $1,450. We'll get you a kit that is a device that has cameras, compute and sensors, and then a wiring harness that plugs into your car. So that wiring harness is specific to a certain brand or a certain model, and it basically, you know, connects to the can bus, which is your car's internal network. And on that network, we can send the same messages that the car already accepts from the factory. And those messages can apply torque to the steering wheel, they can apply gas, and they can apply brake. And when you can control those three axis, you can basically, you know, fully control the car. So, so you can see in this video kind of how that works. There's connectors that connect to this can bus. We can just intercept it and we can send the same messages that the car is designed to receive and that the stock ADAS system of the car would have sent.
  (0:04:23)
- Harald Schafer
  It's just that the stock ADAS systems generally suck and we can make one that is actually usable. All modern Toyotas, even from 2017 onwards, ship with ADAS with the ability to control gas, brake, steering electronically, but they're just not very good and people tend not to use them. But when you use good software like Open Pilot, you can make actually a very enjoyable partial autonomy experience.
  (0:05:10)
- Jason Calcanis
  And so I guess the, well, one question is, how does Toyota, Honda, you know, these, you know, car manufacturers, how do they look at what you're doing? Do they try to stop you? Are they excited about it or are they indifferent?
  (0:05:35)
- Harald Schafer
  Well, they haven't tried to stop us. People that work in kind of the ADAS development there tend to like us. You know, we know quite a few people that work in kind of their research labs and their ADAs. Generally speaking, they like us. They wish their companies would move a lot faster when it comes to this sort of stuff. You know, it's not lost on those engineers that their ADAS solutions are terrible and that compared to something like Tesla or Open Pilot, they're very, very far behind. So generally speaking, they like us.
  (0:05:50)
- Jason Calcanis
  And so 1500 bucks, you put this into your car, you can either install it yourself or there are third party installers, I understand. Who will do this for you?
  (0:06:17)
- Harald Schafer
  No. Well, there might be, but not any that we're affiliated with. It's kind of a DIY thing. It's not that hard. It's like kind of working on your own computer. It's not the hardest thing, but it is a project.
  (0:06:27)
- Jason Calcanis
  Wow, this Jam with JCAL contest has been a blast. So far. I've had the opportunity to meet with four great founders from companies like Core, Pod, Ulama, Uptrends, AI and the Roam app, all because they all use tech domains. And we have room for one more. Do you want to come on the Pod and tell me what you're building? Well, you only need two things to enter. You got to be a founder with under 2 million in funding and you got to have one of those awesome tech domains. So head to Jam with JCAL Tech and tell me what you're building. And if you win, I will invite you onto this week in startups and you'll get to share your vision with me and the world. I'm working with tech domains because killer startups use them. You know, 1x tech, rabbit tech, so many others.
  (0:06:38)
- Jason Calcanis
  And guess what? We use it too. That's right. Tech Powers our Founder Friday program. So tell me about your awesome tech domain and startup. Apply for the Jam with JCAL contest today at JamWithJcal Tech. We're picking the final winner soon. Okay, so the thing I really wanted to talk to you about is the open source approach that you've taken. It seems to me that open source has won so much of the problem space in computing that it's odd to me that all of the self driving companies and projects are closed, whether it's Tesla, Cruise, Waymo or any number of them. So how is the open source project going? Are there many other people contributing to it and do you see interest or engineers from these other major projects? Looking at the work, you're talk to me a little bit about how that space is shaping up and if you believe Open source is going to win the day here.
  (0:07:19)
- Harald Schafer
  Okay, so just to start off with, I mean I have dozens of great things to say about open source, but I think the biggest thing it does for us is it keeps us honest and it prevents us from being able to rent seek. If we make hardware that's quite overpriced or worse than a previous version, someone can just come in, undercut us and run open pilot. If we make changes to the software that makes it just a experience, like we can run ads while you're stationary, stuff like that. People will run a fork and they'll make changes to undo the things that we did. So it really forces us to make a good product both in software and in hardware. So that's I think the biggest thing that's good about open source for that. And then are there a lot of people contributing. So because we support so many different cars, it is useful for the community to be able to port new cars, to port their own car.
  (0:08:19)
- Harald Schafer
  There's definitely a lot of contribution there when it comes to like improving the core driving experience. You know, it's not really feasible for, for external people to contribute there. It's mostly for this like kind of small stuff. Some people make forks that have kind of different UIs or small changes that can kind of inspire us to look at maybe something we can change or changes we can, we can take over.
  (0:09:05)
- Jason Calcanis
  Talk to me about the approach I saw in, you know, our notes here for our discussion. The different approaches people are taking to autonomy and a lot of the work that's being done in Language models is supposedly becoming applicable here. Maybe you could just educate the audience on how this technology was working originally and then how this is starting to evolve over time with the advances in AI.
  (0:09:27)
- Harald Schafer
  I'll just add one final note about the open source discussion, which is that companies that are closed source, it's most likely because they're trying to hide their lack of capabilities. In Silicon Valley, it's pretty common that a lack of transparency means that, you know, they're not, maybe not as great as they claim. But yeah, to answer your other question, we've been very big on end to end machine learning since the beginning, which means we can take data to see how humans drive. It's very easy to collect data on this. You can record their steering gas, brake inputs, you can see the video of the road and you can then learn a machine learning model. You can teach a machine learning model and teach it to drive like that. We've said that since the beginning. You know, when we started this company eight years ago, this wasn't really a big thing.
  (0:09:58)
- Harald Schafer
  Nobody was thinking this way. People had perception systems that would detect all sorts of things about the world with all sorts of sensors. They would then go into some planning logic that makes decisions based on that, based on some rules, and then take driving action. Whereas we've in contrast always said just learn how to do everything like a human. Waymo is a good example of something that has this very classical stack where they detect things, then they have this classical planning algorithm, then they make decisions. But now multiple companies are kind of coming around. Tesla talks a lot about doing end to end learning. There's companies like Wave and a few more that are. This is kind of gaining traction. I think your final point was about the generative AI models, how those, you know, become relevant. So to learn how to drive like a human, one of the best ways to do this is to learn in a simulator.
  (0:10:41)
- Harald Schafer
  So what we do is you have a simulator that can simulate driving and you can then let your student that is learning how to drive, drive in it and it will deviate from what a human would have done. And then you can tell it to recover to what the human was doing. So that's basically how our system works. But that requires a simulator of driving. And one really good way to make a simulator is with these generative AI models that can generate arbitrary video. They can simulate the world, they can simulate physics. And I've got some clips. I don't know if we want to show those now. Yeah, let's take a look at these.
  (0:11:29)
- Jason Calcanis
  I Mean, I think this is sort of the fascinating turn, so to speak, that this is taking, which is in a simulator here that we're seeing for those of you who are listening. We see a simulated road on top and a actual road on the bottom. Explain what we're seeing here.
  (0:12:04)
- Harald Schafer
  So those are both simulated road. They're completely generated by a machine learning model. They're just two different perspectives. One is kind of zoomed in, the other is kind of zoomed out. And then that machine learning model that's simulating the world is also telling you what it thinks a human would do over the next 10 seconds. And so what we can do is we can let this agent drive and by giving action inputs like turn left, turn right, the world model will simulate that deviation and then try to get back to what the human would have done. So this is fully simulated, fully in the imagination of a machine learning model. And we can let a student kind of play and kind of drive around, make mistakes and we can tell it to recover from those mistakes. And so this is what we're working on today.
  (0:12:20)
- Harald Schafer
  We've been working on that for a little over a year now with these generative models and we hope to ship that very soon.
  (0:13:00)
- Jason Calcanis
  So this model has information on what roads look like nighttime versus daytime, rain versus snow versus clear skies. And it will create simulations, let the driver attempt to do that. And then how do you know if it's making a mistake? And then how do you know to intervene? And how do you know it doesn't hallucinate? Right, because that's like one of the things that we all experience using ChatGPT is, hey, sometimes it's pulling information from maybe a website that has bad data. So how do you know? Like, yeah, it's, it's not producing, you know, something that is incongruous to the real world.
  (0:13:08)
- Harald Schafer
  Yeah, I mean, that's, that makes sense. So basically these models are seeded with some real video. So we give them some context that is real video. And then we ask them to basically go from there and simulate and we can give it, you know, actions and then that. Then you basically have a simulator. And yeah, I mean, the hallucinating, it's kind of the same thing as just general inaccuracy. These models, when they're very accurate, you know, they produce realistic looking rollouts. When they're inaccurate, they can deviate from the real world. And that's definitely a real failure mode. You know, you can diverge from what looks like a realistic road lane. Lines can cross in unrealistic Ways. And that's kind of the project of making these models better, is just bringing that error rate down and the videos look better and better.
  (0:13:48)
- Jason Calcanis
  Waymo seems to be the one player that has full autonomous vehicles on the road at scale. Their approach is the old school approach. It's taking all this input and it's saying, you know, if this, then that, and, and you know, it's got a, a rule set there that it's following. So maybe you could tell me why they've been so successful and you know, what, what you think of their rollout limitations on what they're doing and, or things they're doing that are causing them to hit 100,000 paid rides a week.
  (0:14:28)
- Harald Schafer
  Right. Well, let me start by saying, you know, what Waymo's done is incredibly cool. They're probably the coolest service that you can get today as a normal user. That's like an actual robotic thing of something interacting with the real world that is actually to some degree autonomous. With that said, I think their strategy doesn't really make sense from a business perspective. I think, you know, that they don't have unit economics at all. And a part of that is because of this strategy that they're using which requires, you know, mapping all the areas that they drive in. It requires a lot of remote supervision. Not sure how many remote supervisors they have now, but I'm guessing it's on the order of a half to one per car. You know, I just don't think this scales nearly as well as the strategy that we're using, which is far more end to end.
  (0:15:06)
- Jason Calcanis
  What do you mean by remote supervisors?
  (0:15:54)
- Harald Schafer
  So it's hard to get exact numbers on this sort of stuff, but I would guess that they have interventions by remote operators that take some amount of action to fix mistakes at least once every 10 rides. And so it's not clear to me that their strategy that they're applying now, even though they do not have drivers in the car, necessarily scales that easily to actually having a, you know, really, really autonomous fleet that doesn't require humans in the loop, essentially.
  (0:15:57)
- Jason Calcanis
  So there are humans somewhere looking at the cars driving. In your mind, it might be one to one per vehicle or one to two vehicles.
  (0:16:24)
- Harald Schafer
  That would be my guess, yes.
  (0:16:34)
- Jason Calcanis
  And they are not driving the cars, obviously. We actually recently had a startup on that is doing remote driving of cars like a video game over 5G. Pretty clever if you've got good connections and seems to work pretty well for dropping off a dropping off and also training, you know, like a Hertz car or something. Like that. But with Waymo, you think there's a large number of people, obviously that would be very expensive to have, you know, a human being, you know, split. Watching two cars, that's just like having a driver essentially, because these are probably well paid people in an office somewhere. So you have that overhead. So. And then they use LIDAR as well, which adds a certain expense. What do you think the economics are in terms of running one of these Waymo vehicles?
  (0:16:36)
- Harald Schafer
  I mean, from my understanding, they've got over a billion dollars in burn rate and less than a thousand cars. So that's over a million dollars per car per year. Now revenue probably looks on the order of 100 to $150,000 a year. So it's very far off from something that makes sense. And I think some, you know, obviously they can get that down pretty quickly. But I think some of those things will be hard to remove, especially the remote operators, the costs in developing new mapping for all these new areas. I think there are just several issues that will come up that are costly. Like, I don't know what happens now if someone leaves the door open, does the door auto close? That's that sort of stuff I think will make the unit economics essentially not realistically come down to the, you know, 100,000 a year that is required anytime soon.
  (0:17:25)
- Jason Calcanis
  I've been using Tesla's Autopilot and FSD since inception and was using this morning. I get an intervention, I would say in the back roads here in Texas or on the highway once every, I don't know, 20 to 30 minutes. So it feels like it's doing a pretty, pretty great job on straightaways, easy turns, roundabouts. It feels like it's a little jittery. Left turns into traffic, feels a little jittery, like it's figuring some stuff out. But it does feel like it's getting more confident every year. Maybe you could talk a little bit about Waymo's approach versus Tesla FSD versus what you're doing at comma.
  (0:18:12)
- Harald Schafer
  I mean, so Tesla is definitely a lot more similar to us. And if I were to place a bet on anyone, it would be them. They're recently very focused on end to end machine learning, just like we are. I think they've not quite rolled out as end to end of a strategy as we have. I think they've got some more classical stuff in there, but to be fair, they also have capabilities that our system does not have. And I think it is harder to switch to end to end when you have these more capabilities like they can do, you know, left and right hand turns and stuff like that. U turns stuff that we cannot yet do, but they're a little bit less end to end than us. Our system is completely end to end that we ship today. And Tesla is also working on generative AI simulation, presumably to one day train in.
  (0:18:55)
- Harald Schafer
  I don't think they do that yet. I think we would have heard about that if they did. There is a lot of similarity to our approach there. You know, they also have a product, they have a very large fleet. You know, Tesla has the most miles collected on any kind of autonomous system. We have the second, and then Waymo actually has quite a bit less than, than any than any of us. So yeah, I think we're much more similar to Tesla in that sense and much more end to end. Waymo has really seemed to have pigeonholed themselves in this lidar sensor strategy. You know, they don't seem to have any interest in moving away from lidar, which I think is a mistake. The world is.
  (0:19:37)
- Jason Calcanis
  Why is it a mistake?
  (0:20:11)
- Harald Schafer
  Yeah, you know, the arguments they often use is that, you know, it's like more redundancy, it gives you information about the world that cameras could never do. But you know, ultimately the roads are designed for human eyes and good modern cameras can do everything human eyes can do, if not more. And so there's absolutely no reason you can't perfectly drive a car, at least safer than most humans with cameras. It is all a software machine learning problem and I think using things like lidars gives you short term gains, but are long term essentially bottlenecks. So I think it's a detour. I think they'll regret that.
  (0:20:12)
- Jason Calcanis
  What does it cost, do you think, for them to put lidar on these cars? I had heard in the early days, 20, $30,000 per car. I don't know if that's still accurate.
  (0:20:51)
- Harald Schafer
  Last I heard they're paying $120,000 for their cars and I think the cars themselves cost about half that. So I think the entire upgrade must be on the order of $50,000 I think.
  (0:21:02)
- Jason Calcanis
  And then Tesla you think is a couple of thousand dollars and yours obviously is $1,500. Uh, so it could be done for a lot less.
  (0:21:17)
- Harald Schafer
  Yes. I mean also 1500 is what we sell it for. You know, we build the devices for half that. And you know, same for Tesla.
  (0:21:26)
- Jason Calcanis
  Tell me about the cameras you use versus Teslas. Because when you say like, hey, we should be able to be as good or better than a human driver, Humans only see in one direction. They get tired, they have glasses, you know, there's blind spots. If you have cameras all over the car, you're literally could be behaving like maybe 6, 7, 8 human beings in terms of your field of view and then in terms of accuracy. The fidelity of cameras is better than human eyes now. And I would think it's obviously more vigilant than humans. Maybe doesn't need a cup of coffee, it's late at night.
  (0:21:34)
- Harald Schafer
  Yeah, I mean not being distracted is definitely, you know, when we start comparing safety, when we get actual competent self driving systems, you know, that's where the advantage is going to be. No distraction, no drunk driving, no sleeping. I think we're not even quite there yet. We need higher capabilities before we can really improve on that. And as to your comments on cameras, I think it's a distraction to talk about cameras. Even this webcam that I'm using now, which is not a great camera, can let you drive a car pretty well if a competent human was operating behind the wheel with that camera view. There are some things that more cameras will help you with. And you know, for a company like Tesla, I think it completely makes sense to install those cameras. For a company like us, the added hassle of installing more cameras around the car is never going to give the upgrade in performance to make that happen.
  (0:22:14)
- Jason Calcanis
  How many do you use when you do it? Just the front facing one or so.
  (0:23:02)
- Harald Schafer
  We have two cameras facing up. Actually I have a device here that I can show you maybe. So this is the device here. And so we've got a narrow camera and a wide camera to the front. So it's 180 degrees and 40 degrees. And then on the other side we have a driver facing camera that makes sure that you're paying attention. So three cameras total.
  (0:23:06)
- Jason Calcanis
  And what about like on the sides of the vehicle and the reverse cameras, Those could help with changing lanes, etc. So how do you think about lane changing and the next version of your software and hardware?
  (0:23:24)
- Harald Schafer
  So our device has, you know, with the two 180 degree lenses, has 360 degrees so you can see the blind spots. But currently the lane changes are supervised. So you initiate the lane change, you're expected to check the blind spot. And most cars that we support have a blind spot sensor that we can also look at. And so when there's a car in your blind spot detected by the blind spot radar, it will prevent the lane change. But it is a supervisor expect it to look as well.
  (0:23:36)
- Jason Calcanis
  Listen, a strong sales team can make all the difference for a B2B startup. But if you're going to hire sharks, you need to let them hunt and you can't slow them down with compliance hurdles like SOC 2. What is SOC 2? Well, any company that stores customer data in the cloud needs to be SoC2 compliant. If you don't have your SoC2 tight, your sales team can't close major deals. It's that simple. But thankfully, Vanta makes it really easy to get and renew your SoC2 compliance. On average, Vanta customers are compliant in just two to four weeks. Without Vanta, it takes three to five months. Vanta can save you hundreds of hours of work and up to 85% on compliance costs. And Vanta does more than just SoC2. They also automate up to 90% compliance for GDPR, HIPAA and more. So here's your call to action.
  (0:24:05)
- Jason Calcanis
  Stop slowing your sales team down and use Vanta. Get $1,000 off at vanta.com twist that's vanta.com twist for $1,000 off your sock too. What is your handicapping of the space? When will we see this rollout, you know, in a major way with multiple vendors in many cities?
  (0:24:48)
- Harald Schafer
  You're talking about like a Waymo type.
  (0:25:10)
- Jason Calcanis
  Taxi, let's say no human in the, in the driver's seat. We've established now that the majority of miles can be driven safely or safer with a human plus a level 2, 3 system or system. Whatever it is. I guess the question for everybody is when do we remove the expense of the driver and have these fleets of cars everywhere driving people and burritos to their destinations without the expense of a driver?
  (0:25:12)
- Harald Schafer
  So I'm generally a lot more pessimistic than I would say the average. I think there's a lot of hype in the space. I think most of these things are generally overhyped. I think the best thing to do is to look at the orders of magnitude of mistakes and kind of see how that's been trending and extrapolate that. I think exactly what you're talking about is relevant. You have a disengagement that, you know, maybe safety critical, maybe not every few drives, let's say. I think the waymos are similar. They have a bit of a different strategy, but they have remote supervision, remote intervention, let's say a disengagement that is necessary every 10, 20 drives. You know, that's very far away from a system that can drive reliably day after day with absolutely no supervision. So I think you should look at the trends and kind of extrapolate the orders of Magnitudes of mistake and we're still many years away.
  (0:25:43)
- Jason Calcanis
  I think, okay, so many years being 3, 4, 5, 6, 7 somewhere in that range.
  (0:26:30)
- Harald Schafer
  I think predicting past five years is so hard. It's not next year, it's not going to be the year after that. I predict within five years there's going to be nothing that looks like a self driving taxi solution in most cities after that I think predictions are so hard.
  (0:26:36)
- Jason Calcanis
  Why hasn't a major car manufacturer, the Toyotas, Hondas of the world looked at what you're doing in the open source project and just said hey, let's go all in on open source here. That would seem to me to be a tipping point for the industry. If we really want to save lives, why not? You know, why hasn't Cruise open source what they're doing or Waymo or Tesla or one of these? I had the co CEO of Tesla at the all in Summit last week and she said open source isn't a discussion at Waymo. So it does seem like open source tends to win in the long term because of the reasons you stated. But I'm just curious why there isn't a major open source project. You do have open maps as a data repository I believe. I'm not sure if you use it or if it's relevant here, but it would seem OpenStreetMaps.
  (0:26:51)
- Jason Calcanis
  Yeah. And so maybe you could explain a little bit about that project and how that helps you. And then there's all this open hardware that exists in the world now and all kinds of libraries. Why hasn't an open source self driving project kind of taken hold across many vendors yet?
  (0:27:42)
- Harald Schafer
  So first of all, like I said, I think companies don't open source their stuff because they want to overhype what they have. Open sourcing means making clear what you have. And I think companies like Waymo aren't too excited about people finding out how many interventions they actually have about people finding out how much work it actually takes to do a lot of these things because you know, that's their revenue stream is investment. And if people have less of an opinion of where they really are, that is not good for, you know, their financial situation. Tesla on the other hand, they're not open source but they're relatively open and transparent about what they're doing and what the system does and you can use it at any time and you can test it in any conditions that you want. So it's not open source, but at least it's transparent.
  (0:28:01)
- Harald Schafer
  And then as to why these legacy car manufacturers don't Take our system and just implement it and ship it because it's a lot better than theirs. I mean, that I think is a great question, but it's a question for them. I think generally speaking, these companies are not interested in innovation. They run defensively and they act out of fear. If they see that their business model is under threat, they will respond and try to reduce that threat. But when there is a system that is a clear upgrade to them available, that doesn't seem like an immediate threat, they just generally have no interest. I mean, it's the same thing with their infotainment systems. You know, you use infotainment system of even a modern car from a legacy car manufacturer and it feels broken compared to your iPhone. There's no excuse for that. They could fix that, but that's just not how these companies work.
  (0:28:45)
- Harald Schafer
  I think the bigger question is why does companies like Lucid or Rivian, perhaps not. You know, they're developing their own system in house, they have hardware that can run open pilot and they're shipping solutions that are worse than OpenPilot. I think they'd be a great candidate to implement OpenPilot on their car at least while they're developing their own solutions solution. If they can make something better, sure, replace it. But in the meantime, why not just use our software? It's free, it's MIT licensed, they can get something better running today.
  (0:29:30)
- Jason Calcanis
  Yeah, it would seem to me that if you're behind and classically this is what we've seen, when a corporation is behind, they embrace open source and when they're ahead, they embrace closed source. Google is a great microcosm of that. Android, they were far behind on the smartphone market. They open source IT search, they were far ahead. They, they kept it closed. Facebook, the social graph is closed because they're so far ahead and they have lock in and then they just open source llama and they're so far behind on AI that they decided to open source. It's not key to the business. So it would seem to me like a Rivian, a niche provider of vehicles would do so much better to partner with you. Have you, have you talked to them or reached out to them?
  (0:29:54)
- Harald Schafer
  I mean, we're not really interested. Like we have very limited resources. We don't want to invest resources into partnering with anyone. We do everything we can to make our stuff accessible open source. And a company like Rivian, if they invested the time, could easily port it to their hardware. I think it's like a stuff made here kind of thing. They want stuff built in House. That's what I think. There's some limitations to our software too that they may not like. We don't do AEB yet. They might not be interested in a solution that doesn't do a B as well. That's something that we're working on. But you know, we've talked to some of these people, there is some interest. We've talked to legacy car manufacturers. There is interest, but it just doesn't align with our goals. We are really focused on solving robotics and we just want to make money and have a product in the meantime.
  (0:30:38)
- Harald Schafer
  And anything that distracts from that is just not worth it for us.
  (0:31:22)
- Jason Calcanis
  All right. Scaling product is one of the hardest challenges we as founders face. Knowing what to build is obviously only half the battle. You also need the resources at exactly the right time. You might want a little help now, you might not need it later. And that's where Micro One comes in. They're going to help you scale your product with a team of developers in days, not weeks. When you're handling the search process, when you're trying to get great developers, the vetting and the onboarding and the paperwork, that's going to take weeks for each one. It's painful. It's one of the hardest parts about being an entrepreneur. Well, imagine if you just tell AI what you need on an engineering basis and then AI delivers with the team at Micro One exactly what you need. You're going to be in great shape. And Micro One built this incredible AI engine.
  (0:31:25)
- Jason Calcanis
  This is why I invested. They interview 20,000 engineers every month. They pick the top 1% and then they help onboard them into your company. It's simple and it's effective. They do all the legal, they do the compliance, they do the search. You don't have to do a mountain of resumes. You don't have to worry about somebody flaking out. You don't have to budget a huge recruiting bill. Micro One's got you covered and you'll find your next engineer in 48 hours or less. That's the promise micro1 has for you. So here's the call to action. Micro1ai twist m I c r o 1ai slash twist to instantly ramp up your product team. And if you make a hire before October 1st, they're going to give you two weeks of free development per hire. Have you been tracking what's going on in China? There are some places in the world where they might look at self driving and say, hey, even with one intervention every 10 or 20 rides, that's safe enough for how we look at safety in let's say Beijing or China where like, you know, let's face it, people in factories there might have,
  (0:32:11)
- Jason Calcanis
  you know, OSHA in America might be a very fine filter, you know, in terms of working conditions and in China, other places, maybe they're just like, you know, people are a little bit more expendable. We don't, we want to have society move faster and rather than, you know, have very niche safety needs. I'm trying to be generous here, but they've got six or seven different players on the road with technology that I think is similar to yours and Tesla's. Yes.
  (0:33:16)
- Harald Schafer
  I'm not super familiar with what's going on in China in terms of self driving. I think when you're talking about things like rolling out these, these systems with the technology, where it's at today, you cannot make a profitable taxi service. That's just a fact today. And I think we're pretty far away from that. And so companies like Waymo, when they grow, they cost more money and that, that's just not. That to me seems like a terrible strategy. And so I'm not sure what the benefit would be of doing this in China. Even if they're okay with the additional risk, it's not clear to me that that accelerates progress. I think these technical, the strides need to be made and they don't need that much data or they don't. We have more data than Waymo.
  (0:33:46)
- Jason Calcanis
  Yeah. What do you think the Tesla announcement will be? Think Elon will show kind of a two seater that people. There are some leaked photos on social of like, hey, maybe there's going to be a specific physical robotaxi debuted. That seems to be the case. And then do you think it will have a safety driver when they roll it out or is their technology ready to do autonomous rides like Waymos does?
  (0:34:25)
- Harald Schafer
  I think your experience with FSD is probably very reflective of how good Tesla's autonomous software is. I very much doubt that all of a sudden there's some secret project that is capable of doing actual taxi service. You know, Elon said in 2016 that they were going to drive, you know, coast to coast self driving at the end of the year. That didn't happen. I think generally speaking, Elon's a bit optimistic. I think this is probably along those lines.
  (0:34:50)
- Jason Calcanis
  So when do you think if you had to take a guess, they would be able to take the steering wheel out with fsd just to make a wild guess?
  (0:35:15)
- Harald Schafer
  I'd say again over five years, under five years, five plus. Years, I would say yes.
  (0:35:25)
- Jason Calcanis
  As we wrap up here, tell me what your vision is for robotics. Obviously you have humane. You got Tesla doing Optimus. We just had Sergey at the all in Summit, you know, sort of. I think he was lamenting a little bit. They were early into robotics before AI was there. You know, cars go very fast, they can cause a lot of damage. But a robot, you know, if it's weighs 50 pounds or 100 pounds, it's not going to do a lot of damage. If it falls over, it's not going to certainly be going 65 or 75 miles an hour when it makes a mistake. So tell me a little bit about what you think the future of robotics is, given what you've learned in AI and what's your approach for that.
  (0:35:30)
- Harald Schafer
  I mean, I'm very excited about robotics. That's, you know, having robots in your house that could do your laundry or anything like that. That is the coolest thing ever. And, you know, I think about that all the time. But I think we should be realistic. The big reason a lot of people went to self driving 10 years ago, including me, is because it seemed like a great applied robotics problem. That was easy. You have two dimensional actuators, you have simple rules of the road. As far as robotics goes, that's relatively easy. And then what happened is all these companies were optimistic and ended up not reaching their goals. And now all of a sudden everyone's switching to humanoid robotics, which from the beginning we always thought was harder. So I think it's just another hype wave. I don't think there's going to be humanoid robots in your house.
  (0:36:11)
- Harald Schafer
  I have a robot vacuum. I think that's kind of the state of the art robots you can buy in your house today. And they get better every year, not super fast, but I think seeing that trend is what, what you should be thinking about, about realistically what's going to happen. Those things will get better, but you're not going to have humanoid robotics in a couple of years. I think it's just another hype cycle and we should be somewhat cautious about everything that's just a demo and is not shipping.
  (0:36:51)
- Jason Calcanis
  Got it? Yeah, it does. And where do you think the first applications will be? In robotics factories and doing very like specific narrow factory work versus, hey, you know, this thing's walking around the ranch, you know, going and cleaning up, you know, horse poop and putting hay out for the horses.
  (0:37:16)
- Harald Schafer
  Yeah, I mean, I think it's just going to be along the lines of what we've been seeing Right. They've been factory robots for a long time. I think they'll become easier to program. They'll be able to do more things without needing to make custom hardware. You know, we have robot vacuums, robot mops. I think someday they'll stop eating your cables and they'll stop eating your socks. You know, there's robot lawnmowers. I think I see one of those in Texas.
  (0:37:35)
- Jason Calcanis
  I was driving by and somebody, or I was walking by rather, I just parked and somebody had one on their front lawn. And it's at night, it's got the light on and it's out there at night running because I guess it's too hot here during the day in Texas.
  (0:37:58)
- Harald Schafer
  Yeah, exactly. I mean, it's great. I think, you know, I think those are the things we should be excited about. We should be excited about the things that people are shipping, not the demos we're seeing. And those things are getting better and I think they'll continue to get better. And you know, I'd be excited if in 5 years my robot vacuum doesn't get stuck anymore. I have a robot mop and maybe, you know, something that can fold my laundry. But I think we should dampen expectations from this human mind stuff.
  (0:38:10)
- Jason Calcanis
  Is it going to be an open source project as well when you start doing the robotics stuff?
  (0:38:33)
- Harald Schafer
  Yeah. So OpenPilot is on the one hand an open source robotics operating system and on another hand it's a, you know, ADAS system and we're kind of working on splitting those out. And the self driving part is going to be one application. We imagine there's going to be models running that are kind of world models that have a general understanding of video and physics and how the world moves and more and more applications will work. I mean we have a very impromptu robot that we built a while back that's in the background here, which we call the comma body. It's just a bunch of wheels for our device. And you know, we are will be more interested in getting into that if it's feasible with end to end machine learning to make something that navigates around your house or your office without getting stuck and without doing anything stupid.
  (0:38:38)
- Harald Schafer
  And today that's actually not that easy.
  (0:39:24)
- Jason Calcanis
  Yeah, there's a lot of detrius around most people's houses and things change pretty frequently.
  (0:39:27)
- Harald Schafer
  Exactly.
  (0:39:33)
- Jason Calcanis
  Kind of the opposite of a highway where you just have cars and nothing else. Well, listen, continued success and where can people find out more about the self driving project and also the open source project?
  (0:39:34)
- Harald Schafer
  Yeah, so I mean our website Commodore AI, if you want to check out our device, you know, try it out, don't listen to what other people are saying. If you don't like it, send it back. And you know, our GitHub has all of our open source projects and open pilots on there. You can see what we're working on. We don't do anything in secret. If we're not publicly sharing it, it's probably not something we're doing.
  (0:39:48)
- Jason Calcanis
  I mean, I love the idea of. Yeah, I would love to see Waymo's code base and understand how these mission control specialists actually interact. I know that was like a big controversy for them when I had mentioned it previously. They seem a little bit upset about like people even discussing that there could be interventions or crews and then what are the interventions that are occurring? I think some transparency there would be good and I think regulators now are, you know, very interested in double clicking maybe and seeing what's under the hood. Right?
  (0:40:08)
- Harald Schafer
  Yeah, no, I think so. I mean, I would love to see more transparency. It's something we, we really strive for and you know that that's, that's the best way to do it, I think.
  (0:40:42)
- Jason Calcanis
  Yeah. Regulators, if you're listening, I think all interventions should be reported in public. I think that would be a good starting point. Right. Like if they have a log of interventions, share the interventions. I think also sharing the videos of any intervention that occurs, you know, with regulators to review on some regular basis because, you know, seems to be one of the great second order effects of what you're doing is you're going to be able to tell regulators and city planners, hey, this is where stop signs need to be. This is where red lights need to be. This is where the speed limit could be higher. This is where the speed limit should be lower. And they don't actually have a way of, you know, in the real world getting tens of millions of miles of data and, you know, for this. Except I think they lay down like a little strip that counts the number of cars going by and the speed of those cars.
  (0:40:50)
- Jason Calcanis
  It's not, it's pretty, pretty dumb information.
  (0:41:45)
- Harald Schafer
  Yeah, no, they definitely don't have modern data gathering techniques. I've got a map open here of our cars that are driving over the last week. I don't know if you want to see that.
  (0:41:47)
- Jason Calcanis
  Wow. Yeah, show me that. Yeah, I love a good visualization. Yeah.
  (0:41:54)
- Harald Schafer
  So here you can see kind of, this is I think last week or last 30 days, I'm not exactly sure. Oh, last 30 days. Yeah, you can see. I mean, it's pretty global. In the US We've got really quite good coverage actually of basically all the urban areas and it's a bit more sporadic.
  (0:41:58)
- Jason Calcanis
  The areas you don't have in the Midwest are simply because we don't have population there and there's a couple of mountain ranges there, so.
  (0:42:12)
- Harald Schafer
  Yeah, exactly.
  (0:42:18)
- Jason Calcanis
  Some of those arteries you're seeing are the ones that go through the Rocky Mountains and the Sierra has much to do and population density. You know, when you see Florida and California and the Northeast lit up, there was a reason. And you see people driving to Tahoe. That's really, you know, powerful visualization. You got a couple people in Alaska using it as well. These people are hobbyists. Yeah. And they, they're technologists who really are thinking about the future of this technology and they want to contribute to the project. Or are you finding, like, you have corporations using it for some reason?
  (0:42:19)
- Harald Schafer
  There are definitely some corporations, I think, generally using it out of interest to compare with their own system. You know, a lot of, like, people that are working on ADAs. Yeah. Most of this are just users. You know, you buy the Device, it takes 20 minutes to install in your car, and it makes your life a bit easier if you're doing a lot of driving. Yeah.
  (0:42:59)
- Jason Calcanis
  And yeah, it looks like you're popular down under as well. And when you see Australia, it's a very large landmass. People don't understand how big Australia is and how not populated is. When you go to the west of Australia, there are signs that just say, like, there's no coverage here. There's nobody coming to help you. Make sure you have water, extra tires, extra food, extra jacks, a satellite phone. Because, man, those deserts out there are barren. And they're barren for, you know, days and days. If you get caught out there, you're dead. You will, you will.
  (0:43:15)
- Harald Schafer
  But the great Australian desert here, no data from there yet, unfortunately.
  (0:43:52)
- Jason Calcanis
  I mean, if there's data from there, I mean, if you were to take a car there, I, I've watched some videos of people, you know, driving through that area. In Australia. The key thing is, like, how much weight of extra fuel can you bring with you on your car? They're like adding, you know, half the car is filled with gas canisters, basically when you're driving across, because there's no gas stations, folks, you're going to die out there if you go and you run out of gas.
  (0:43:56)
- Harald Schafer
  So, yeah, it's a real adventure project.
  (0:44:22)
- Jason Calcanis
  This is interesting. So here's your. These metrics, I'm assuming, are public that you put out.
  (0:44:25)
- Harald Schafer
  They're not public, but I mean, we're not secretive about them. But yeah, we can see here this is some general dashboard we have. You can see how much percentage of miles are engaged in the fleet right now. So it's a bit over 50%. How much time of the driving is engaged?
  (0:44:30)
- Jason Calcanis
  People love to use it on the highway, I assume, right? That's like super low. I mean, my fatigue level goes way down. When I was driving between San Francisco and Tahoe using my Tesla, I mean, when I would drive my Suburban, which was my go car, if batteries don't work out and that's the end of the world and it's an apocalypse, I like to have one of each man. I mean, my fatigue level from one car versus the other just staying in the lane. And then also people in the car prefer when I'm using fsd, I find, because less motion. Right. It's a, it's, it's a better ride.
  (0:44:44)
- Harald Schafer
  Yeah, no, I hear that a lot. My wife always says. Well, did you disengage? It feels much worse now.
  (0:45:22)
- Jason Calcanis
  Yeah, well, I mean, that's very specific to you and your. I mean, you may be making a great system for self driving, but she, she has complained to me about your inability to stay in the center lane. More work to be done there, Harold.
  (0:45:27)
- Harald Schafer
  Exactly.
  (0:45:39)
- Jason Calcanis
  Listen, I appreciate you coming on the program and we'll see you all next time on this week in startups.
  (0:45:40)

Transcript
Claims

- Harald Schafer
  Humanoid robotics is just another hype wave and there won't be humanoid robots in people's houses anytime soon.
  (0:00:00)
- Harald Schafer
  Companies that shifted to humanoid robotics after failing in self-driving were overly optimistic and didn't reach their goals.
  (0:00:00)
- Jason Calcanis
  The autonomy endgame is upon us, as evidenced by companies like Waymo and Tesla advancing in vertical takeoff and landing.
  (0:00:37)
- Harald Schafer
  Comma AI sells a kit that runs software called Open Pilot, which is completely open source and an ADAS upgrade for cars, allowing for level two autonomy.
  (0:02:18)
- Harald Schafer
  Over 50% of miles driven by Comma AI users are done using Open Pilot.
  (0:02:18)
- Harald Schafer
  People working in ADAS development at car manufacturers like the work being done by Comma AI, compared to their current systems.
  (0:05:50)
- Harald Schafer
  Generally, ADAS solutions from major car manufacturers are considered to be far behind compared to Tesla's or Open Pilot's solutions.
  (0:05:50)
- Harald Schafer
  Open source software keeps companies honest and prevents rent-seeking by allowing others to undercut overpriced or subpar products.
  (0:08:18)
- Harald Schafer
  Companies that are closed source likely hide their lack of capabilities.
  (0:09:58)
- Harald Schafer
  Comma AI, from its inception, has focused on end-to-end machine learning to collect data on how humans drive and to develop its technology.
  (0:09:58)
- Harald Schafer
  While Waymo's autonomous service is impressive, its business strategy does not make sense due to lack of unit economics.
  (0:15:06)
- Harald Schafer
  Waymo requires extensive mapping and remote supervision for its service, which may involve one remote supervisor per car.
  (0:15:06)
- Harald Schafer
  Waymo burns over a billion dollars annually with less than a thousand cars, resulting in costs of over a million dollars per car per year.
  (0:17:25)
- Harald Schafer
  The revenue for Waymo vehicles is likely around $100,000 to $150,000 per year, which does not cover their high operating costs.
  (0:17:25)
- Harald Schafer
  Tesla's approach to self-driving with end-to-end machine learning is likely to be successful, and if betting, one would bet on Tesla over Waymo.
  (0:18:55)
- Harald Schafer
  Waymo's reliance on lidar is a strategic error, providing short-term gains but becoming a long-term bottleneck.
  (0:18:55)
- Harald Schafer
  The rollout of self-driving taxi solutions across many cities is many years away, possibly over five years.
  (0:25:43)
- Harald Schafer
  Reliable autonomous driving requires reducing disengagement rates, which currently occur every few drives.
  (0:25:43)
- Harald Schafer
  Companies avoid open source to obscure their actual capabilities and overhype what they have to attract investment.
  (0:27:42)
- Harald Schafer
  Tesla is relatively open about what its autonomous systems do, though they are not open source.
  (0:27:42)
- Harald Schafer
  Legacy car manufacturers prefer to act defensively and resist innovative solutions unless their business model is under threat.
  (0:28:45)
- Harald Schafer
  Legacy car manufacturers' infotainment systems are often inferior compared to modern consumer electronics, like iPhones.
  (0:28:45)
- Harald Schafer
  Having robots in your house that could do your laundry or similar tasks is the coolest thing ever.
  (0:36:11)
- Harald Schafer
  The big reason a lot of people went to self-driving 10 years ago is because it seemed like an easy applied robotics problem.
  (0:36:11)
- Harald Schafer
  Companies were optimistic about self-driving and ended up not reaching their goals.
  (0:36:11)
- Harald Schafer
  Switching focus to humanoid robotics is just another hype wave.
  (0:36:11)
- Harald Schafer
  There are not going to be humanoid robots in people's houses.
  (0:36:11)
- Harald Schafer
  A robot vacuum represents the state of the art in household robots today.
  (0:36:51)
- Harald Schafer
  Humanoid robotics will not be available in a couple of years.
  (0:36:51)
- Harald Schafer
  Factory robots will become easier to program and will be able to do more things without needing to make custom hardware.
  (0:37:35)
- Harald Schafer
  Robot vacuums and mops will improve, like stopping eating cables and socks.
  (0:37:35)
- Harald Schafer
  People should be excited about robotics that are actually being shipped, not just demos.
  (0:38:10)
- Harald Schafer
  In 5 years, robot vacuums will not get stuck anymore.
  (0:38:10)
- Harald Schafer
  Expectations for humanoid robotics should be dampened.
  (0:38:10)
- Harald Schafer
  OpenPilot is an open source robotics operating system and an ADAS system.
  (0:38:38)
- Harald Schafer
  More applications will work with models running that have a general understanding of video and physics.
  (0:38:38)
- Harald Schafer
  It's not easy today to make a robot navigate around a house or office without getting stuck.
  (0:38:38)
- Jason Calcanis
  Seeing Waymo's code base and understanding interactions with mission control specialists would be interesting.
  (0:40:08)
- Jason Calcanis
  Regulators are interested in scrutinizing autonomous vehicle interventions.
  (0:40:08)
- Jason Calcanis
  All interventions in autonomous driving should be reported publicly.
  (0:40:50)
- Jason Calcanis
  Sharing videos of interventions with regulators would be beneficial and provide real-world data for city planning.
  (0:40:50)
- Jason Calcanis
  Regulators currently lack tens of millions of miles of real-world data to assess where traffic infrastructure changes should be made.
  (0:40:50)

×

## Assign Speakers